==> cxf-services-xkms-common-3.3.10-sources.jar: org/apache/cxf/xkms/model/xkms/ResultMajorEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for ResultMajorEnum.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * &lt;pre&gt;
 * &amp;lt;simpleType name="ResultMajorEnum"&amp;gt;
 *   &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Success"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#VersionMismatch"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Sender"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Receiver"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Represent"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Pending"/&amp;gt;
 *   &amp;lt;/restriction&amp;gt;
 * &amp;lt;/simpleType&amp;gt;
 * &lt;/pre&gt;
 * 
 */
@XmlType(name = "ResultMajorEnum")
@XmlEnum
public enum ResultMajorEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Success")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SUCCESS("http://www.w3.org/2002/03/xkms#Success"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#VersionMismatch")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_VERSION_MISMATCH("http://www.w3.org/2002/03/xkms#VersionMismatch"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Sender")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SENDER("http://www.w3.org/2002/03/xkms#Sender"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Receiver")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_RECEIVER("http://www.w3.org/2002/03/xkms#Receiver"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Represent")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REPRESENT("http://www.w3.org/2002/03/xkms#Represent"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Pending")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PENDING("http://www.w3.org/2002/03/xkms#Pending");
    private final String value;

    ResultMajorEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static ResultMajorEnum fromValue(String v) {
        for (ResultMajorEnum c: ResultMajorEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> cxf-services-xkms-common-3.4.6-sources.jar: org/apache/cxf/xkms/model/xkms/ResultMajorEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ResultMajorEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>
 * &lt;simpleType name="ResultMajorEnum"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Success"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#VersionMismatch"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Sender"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Receiver"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Represent"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Pending"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ResultMajorEnum")
@XmlEnum
public enum ResultMajorEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Success")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SUCCESS("http://www.w3.org/2002/03/xkms#Success"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#VersionMismatch")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_VERSION_MISMATCH("http://www.w3.org/2002/03/xkms#VersionMismatch"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Sender")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SENDER("http://www.w3.org/2002/03/xkms#Sender"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Receiver")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_RECEIVER("http://www.w3.org/2002/03/xkms#Receiver"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Represent")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REPRESENT("http://www.w3.org/2002/03/xkms#Represent"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Pending")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PENDING("http://www.w3.org/2002/03/xkms#Pending");
    private final String value;

    ResultMajorEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static ResultMajorEnum fromValue(String v) {
        for (ResultMajorEnum c: ResultMajorEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
